#!/usr/bin/env python
# -*- coding: utf-8 -*-

import mlt

p = mlt.Properties()
p.anim_set("foo", "bar", 10)
a = p.get_anim("bar")
print "bar is valid:", a.is_valid()
a = p.get_anim("foo")
print "foo is valid:", a.is_valid()
print "serialize:", a.serialize_cut()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Import required modules
import mlt

# Start the mlt system
mlt.Factory().init( )

# Create the consumer
c = mlt.Consumer( mlt.Profile(), "avformat" )

# Ask for video codecs supports
c.set( 'vcodec', 'list' )

# Start the consumer to generate the list
c.start()

# Get the vcodec property
codecs = mlt.Properties( c.get_data( 'vcodec' ) )

# Print the list of codecs
for i in range( 0, codecs.count()):
	print codecs.get( i )
